@@ -5,7 +5,10 @@ use IO::Select;
 use GRID::Machine;
 use Time::HiRes qw(time gettimeofday tv_interval);
 
-my @machine = qw{beowulf orion nereida};
+#my @machine = qw{nereida beowulf orion};
+#my @machine = qw{nereida nereida nereida nereida};
+my @machine = qw{127.0.0.1 127.0.0.2 127.0.0.3 127.0.0.4};
+#my @machine = qw{beo chum};
 my $nummachines = @machine;
 my %machine; # Hash of GRID::Machine objects
 #my %debug = (beowulf => 12345, orion => 0, nereida => 0);
@@ -44,7 +47,7 @@ for (@machine){
   die "Can't execute 'pi'\n" unless $m->_x("pi")->result;
 
   $machine{$_} = $m;
-  last unless $i++ < $np;
+  last unless ++$i < $np;
 }
 
 my $t0 = [gettimeofday];
@@ -128,3 +131,50 @@ real    0m13.700s
 user    0m0.952s
 sys     0m0.240s
 
+# 2 veces nereida
+pp2@nereida:~/LGRID_Machine/examples$ time gridpipes.pl 2 1000000000
+Process 0: machine = 127.0.0.1 partial = 1.570796 pi = 1.570796
+Process 1: machine = 127.0.0.2 partial = 1.570796 pi = 3.141592
+Pi = 3.141592. N = 1000000000 Time = 16.38121
+
+real    0m17.849s
+user    0m0.504s
+sys     0m0.212s
+
+******************************************
+con -O 3 en gcc
+pp2@nereida:~/LGRID_Machine/examples$ time gridpipes.pl 4 1000000000
+Process 3: machine = 127.0.0.4 partial = 0.785398 pi = 0.785398
+Process 0: machine = 127.0.0.1 partial = 0.785398 pi = 1.570796
+Process 1: machine = 127.0.0.2 partial = 0.785398 pi = 2.356194
+Process 2: machine = 127.0.0.3 partial = 0.785398 pi = 3.141592
+Pi = 3.141592. N = 1000000000 Time = 18.508143
+
+real    0m21.299s
+user    0m0.840s
+sys     0m0.360s
+pp2@nereida:~/LGRID_Machine/examples$ time gridpipes.pl 2 1000000000
+Process 1: machine = 127.0.0.2 partial = 1.570796 pi = 1.570796
+Process 0: machine = 127.0.0.1 partial = 1.570796 pi = 3.141592
+Pi = 3.141592. N = 1000000000 Time = 16.552487
+
+real    0m18.076s
+user    0m0.504s
+sys     0m0.188s
+pp2@nereida:~/LGRID_Machine/examples$ time gridpipes.pl 3 1000000000
+Process 1: machine = 127.0.0.2 partial = 1.047198 pi = 1.047198
+Process 0: machine = 127.0.0.1 partial = 1.047198 pi = 2.094396
+Process 2: machine = 127.0.0.3 partial = 1.047198 pi = 3.141594
+Pi = 3.141594. N = 1000000000 Time = 17.372372
+
+real    0m19.461s
+user    0m0.696s
+sys     0m0.240s
+pp2@nereida:~/LGRID_Machine/examples$ time gridpipes.pl 1 1000000000
+Process 0: machine = 127.0.0.1 partial = 3.141593 pi = 3.141593
+Pi = 3.141593. N = 1000000000 Time = 32.968117
+
+real    0m33.858s
+user    0m0.336s
+sys     0m0.128s
+
